dpkt
====

**A fast, simple packet creation/parsing python module with definitions for the basic TCP/IP protocols.**

[![travis](http://img.shields.io/travis/kbandla/dpkt.svg)](https://travis-ci.org/kbandla/dpkt)
[![coveralls](http://img.shields.io/coveralls/kbandla/dpkt.svg)](https://coveralls.io/r/kbandla/dpkt)
[![landscape](https://landscape.io/github/kbandla/dpkt/master/landscape.svg)](https://landscape.io/github/kbandla/dpkt/master)
[![version](http://img.shields.io/pypi/v/dpkt.svg)](https://pypi.python.org/pypi/dpkt)
[![downloads](https://img.shields.io/pypi/dm/dpkt.svg)](https://pypi.python.org/pypi/dpkt)

[![wheel](https://img.shields.io/pypi/wheel/dpkt.svg)](https://pypi.python.org/pypi/dpkt)
[![supported-versions](https://img.shields.io/pypi/pyversions/dpkt.svg)](https://pypi.python.org/pypi/dpkt)
[![supported-implementations](https://img.shields.io/pypi/implementation/dpkt.svg)](https://pypi.python.org/pypi/dpkt)
[![On Deck](https://badge.waffle.io/kbandla/dpkt.svg?label=on%20deck&title=On%20Deck)](http://waffle.io/kbandla/dpkt)
[![In Progress](https://badge.waffle.io/kbandla/dpkt.svg?label=in%20progress&title=In%20Progress)](http://waffle.io/kbandla/dpkt)

Installation
------------

    pip install dpkt

Documentation
-------------

**[dpkt.readthedocs.org](https://dpkt.readthedocs.org/)**


About
-----

This code is based on [dpkt code](https://code.google.com/p/dpkt/) lead
by Dug Song and is now being maintained and improved by an extended set of [contributors](https://dpkt.readthedocs.org/en/latest/authors.html)
 and [developers](https://github.com/kbandla/dpkt/graphs/contributors).


#### LICENSE

BSD 3-Clause